@@ -1,10 +1,12 @@
-###################################################################################
-########################### findAndTransformDates #################################
-###################################################################################
+###################################################################################################
+########################### findAndTransformDates #################################################
+###################################################################################################
 #' Identify date columns
 #' 
 #' Find and transform dates that are hidden in a character column. \cr
 #' It use a bunch of default formats, and you can also add your own formats.
+#' @param cols List of column(s) name(s) of dataSet to look into. To check all all columns, set it 
+#'  to "auto". (characters, default to "auto")
 #' @param dataSet Matrix, data.frame or data.table
 #' @param formats List of additional Date formats to check (see \code{\link{strptime}})
 #' @param n_test Number of non-null rows on which to test (numeric, default to 30)
@@ -28,6 +30,8 @@
 #' \item \code{SOLVE} function will try to solve ambiguity by going through more lines, so will be slower. 
 #' If it is able to solve it, it will transform the column, if not it will print the various acceptable formats.
 #' }
+#' If there are some columns that have no chance to be a match think of removing them from \code{cols} 
+#' to save some computation time.
 #' @return dataSet set (as a data.table) with identified dates transformed by \strong{reference}.
 #' @examples
 #' # Load exemple set
@@ -50,7 +54,7 @@
 #' }
 #' # "##NOT RUN:" mean that this example hasn't been run on CRAN since its long. But you can run it!
 #' @export
-findAndTransformDates <- function(dataSet, formats = NULL, n_test = 30, ambiguities = "IGNORE", verbose = TRUE){
+findAndTransformDates <- function(dataSet, cols = "auto", formats = NULL, n_test = 30, ambiguities = "IGNORE", verbose = TRUE){
   ## Working environement
   function_name <- "findAndTransformDates"
   
@@ -60,12 +64,14 @@ findAndTransformDates <- function(dataSet, formats = NULL, n_test = 30, ambiguit
   if (!is.character(ambiguities) || ! ambiguities %in% c("IGNORE", "WARN", "SOLVE")){
     stop(paste0(function_name, ": ambiguities should be either IGNORE, WARN or SOLVE."))
   }
+  cols <- real_cols(dataSet, cols, function_name)
   ## initialization
   start_time <- proc.time()
   
   ## Computation
   # First we find dates
-  formats_found <- identifyDates(dataSet, formats = formats, n_test = n_test, ambiguities = ambiguities, verbose = verbose)
+  formats_found <- identifyDates(dataSet, cols = cols, formats = formats, n_test = n_test, 
+                                 ambiguities = ambiguities, verbose = verbose)
   if (verbose){
     printl(function_name, ": It took me ", round( (proc.time() - start_time)[[3]], 2), "s to identify formats")
   }
@@ -92,6 +98,8 @@ findAndTransformDates <- function(dataSet, formats = NULL, n_test = 30, ambiguit
 #' 
 #' Function to identify dates columns and give there format. It use a bunch of default formats. But you can also add your own formats.
 #' @param dataSet Matrix, data.frame or data.table
+#' @param cols List of column(s) name(s) of dataSet to look into. To check all all columns, set it 
+#'  to "auto". (characters, default to "auto")
 #' @param formats List of additional Date formats to check (see \code{\link{strptime}})
 #' @param n_test Number of non-null rows on which to test (numeric, default to 30)
 #' @param ambiguities How ambiguities should be treated (see details in ambiguities section)
@@ -126,7 +134,7 @@ findAndTransformDates <- function(dataSet, formats = NULL, n_test = 30, ambiguit
 #' # using the findAndTransformDates
 #' identifyDates(messy_adult, n_test = 5)
 #' @export
-identifyDates <- function(dataSet, formats = NULL, n_test = 30, ambiguities = "IGNORE", verbose = TRUE){
+identifyDates <- function(dataSet, cols = "auto", formats = NULL, n_test = 30, ambiguities = "IGNORE", verbose = TRUE){
   ## Working environement
   function_name <- "identifyDates"
   
@@ -134,7 +142,7 @@ identifyDates <- function(dataSet, formats = NULL, n_test = 30, ambiguities = "I
   dataSet <- checkAndReturnDataTable(dataSet)
   n_test <- control_nb_rows(dataSet = dataSet, nb_rows = n_test, function_name = function_name, variable_name = "n_test")
   is.verbose(verbose)
-  
+  cols <- real_cols(dataSet, cols, function_name)
   ## Initialization
   formats_found <- list()
   format <- NULL # Initialize format to NULL to avoid considering it by mistake as the function format
@@ -142,7 +150,7 @@ identifyDates <- function(dataSet, formats = NULL, n_test = 30, ambiguities = "I
   if (verbose){ 
     pb <- initPB(function_name, names(dataSet))
   }
-  for ( col in names(dataSet) ){ 
+  for ( col in cols){ 
     # We search dates only in characters
     if (is.character(dataSet[[col]]) || is.numeric(dataSet[[col]]) || (is.factor(dataSet[[col]]) & is.character(levels(dataSet[[col]])))){
       # Look for the good format
@@ -207,7 +215,7 @@ identifyDatesFormats <- function(dataSet, formats, n_test = 30, ambiguities="IGN
     data_sample <- findNFirstNonNull(levels(dataSet), n_test)
   }
   else{
-    data_sample <- findNFirstNonNull(dataSet, n_test)
+    data_sample <- unique(findNFirstNonNull(dataSet, n_test))  # Take unique to avoid useless computations
   }
   
   ## Computation
@@ -231,18 +239,27 @@ identifyDatesFormats <- function(dataSet, formats, n_test = 30, ambiguities="IGN
       defaultDateFormats <- getPossibleDatesFormats(date_sep_tmp, date_hours = date_hours)
       formats_tmp <- unique(c(defaultDateFormats, formats))
       
+      # # Check if we should change local time (ie: should it be english?) => Future, because it as to be changed is setColAsDate too
+      # change_lc_time <- any(grepl("Aug|May|Apr", data_sample))
+      
+      # if (change_lc_time){
+        # store_loctime <- Sys.getlocale("LC_TIME")
+        # Sys.setlocale("LC_TIME", "C")
+      # }
+      #  Check formats
       for (format in formats_tmp){
         converted <- as.POSIXct(data_sample, format = format)
         un_converted <- format(converted, format = format)
         if (control_date_conversion(un_converted, data_sample)){
+		  temp_format <- c(temp_format, format)
           if (ambiguities == "IGNORE"){ # If don't care about possible ambiguities: return found format
-            return(format)
-          }
-          else{ # Else keep searching
-            temp_format <- c(temp_format, format)
+            break
           }
         }
       }
+      # if (change_lc_time){ # Reset it
+        # Sys.setlocale("LC_TIME", store_loctime)
+      # }
     }
     if (is.numeric(data_sample)){
       temp_format <- identifyTimeStampsFormats(dataSet = data_sample)
@@ -394,7 +411,8 @@ getPossibleDatesFormats <- function(date_sep =  c("," , "/", "-", "_", ":"), dat
     }
   }
   
-  # Complete the list with the same formats but with a time format at the and separed by a ' ' or a "T" and optionaly with a "Z" at the end
+  # Complete the list with the same formats but with a time format at the and separed by 
+  # a ' ' or a "T" and optionaly with a "Z" at the end
   formats <- c(datesFormats, hours_format)
   if (date_hours){
     for (datesFormat in datesFormats){
@@ -404,6 +422,9 @@ getPossibleDatesFormats <- function(date_sep =  c("," , "/", "-", "_", ":"), dat
     }
   }
   
+  # Add optional time zone at the end.
+  # formats <- c(formats, paste(formats, "%z"))
+  
   ## Wrapp-up
   return(formats)
 }
@@ -413,6 +434,8 @@ getPossibleDatesFormats <- function(date_sep =  c("," , "/", "-", "_", ":"), dat
 ############################### Format for parse_date_time ############################
 #######################################################################################
 # Code is commented and result hard written so that it's way faster. You should keep it that way
+#' @importFrom lubridate parse_date_time
+#' @importFrom stringr str_replace_all
 formatForparse_date_time<- function(){
   # Get complete liste of format
   # listOfFastFormat <- getPossibleDatesFormats()
@@ -444,7 +467,6 @@ formatForparse_date_time<- function(){
               "ydm H", "dmy HMS", "dmy HM", "dmy H", "mdy HMS", "mdy HM", "mdy H"
   )
   
-  
   ## Wrapp-up
   return(result)
 }
